summaryrefslogtreecommitdiff
path: root/include
diff options
context:
space:
mode:
authorChristopher Sherlock <chris.sherlock79@gmail.com>2024-11-14 00:38:25 +1100
committerMichael Weghorn <m.weghorn@posteo.de>2024-12-04 18:51:24 +0100
commit48d0d525d0cc579be2b1ba195ee797fd6f670276 (patch)
tree6d8bd332696e27921f01b0229231e05786b9df7b /include
parent285b66443303b8e240a6af48adb1f58bf4f8644e (diff)
vcl: fix call sites for createBlendFrame(), rename to createAlphaBlendFrame()
The call sites are actually passing in transparency, in fact to be consistent with current conventions we are actually dealing with alpha values. So we need to take the transparent values at the call sites and convert to alpha values by just subtracting 255. Hence fixing the FIXME comment. Change-Id: Ibc55ea77f469ec8afcab0cc26d2b8cdf25ea8a72 Reviewed-on: https://gerrit.libreoffice.org/c/core/+/173858 Tested-by: Jenkins Reviewed-by: Michael Weghorn <m.weghorn@posteo.de>
Diffstat (limited to 'include')
-rw-r--r--include/vcl/bitmapex.hxx9
1 files changed, 4 insertions, 5 deletions
diff --git a/include/vcl/bitmapex.hxx b/include/vcl/bitmapex.hxx
index b102ced8ba9b..ebc56930192e 100644
--- a/include/vcl/bitmapex.hxx
+++ b/include/vcl/bitmapex.hxx
@@ -467,7 +467,7 @@ private:
};
/** Create a blend frame as BitmapEx
@param nAlpha
The blend value defines how strong the frame will be blended with the
@@ -480,14 +480,13 @@ private:
@param rSize
The size of the frame in pixels
*/
-BitmapEx VCL_DLLPUBLIC createBlendFrame(
+BitmapEx VCL_DLLPUBLIC createAlphaBlendFrame(
const Size& rSize,
sal_uInt8 nAlpha,
Color aColorTopLeft,
Color aColorBottomRight);
-
-/** Create a blend frame as BitmapEx
+/** Create a blend frame as BitmapEx using an alpha value
@param nAlpha
The blend value defines how strong the frame will be blended with the
@@ -499,7 +498,7 @@ BitmapEx VCL_DLLPUBLIC createBlendFrame(
@param rSize
The size of the frame in pixels
*/
-BitmapEx createBlendFrame(
+BitmapEx createAlphaBlendFrame(
const Size& rSize,
sal_uInt8 nAlpha,
Color aColorTopLeft,
@@ -467,7 +467,7 @@ private:
};
-/** Create a blend frame as BitmapEx
+/** Create a blend frame as BitmapEx using an alpha value
The blend value defines how strong the frame will be blended with the